@@ -483,7 +483,7 @@ function show_stacked_graphs($clustername,
   $tpl_data->assign("stacked_graph_args", $stacked_args);
 }
 
-function get_load_heatmap($hosts_up, $host_regex, $metrics, $tpl_data, $sort) {
+function get_load_heatmap($hosts_up, $host_regex, $metrics, $load_scale, $tpl_data, $sort) {
   foreach ($hosts_up as $host => $val) {
   // If host_regex is defined
   if (isset($host_regex) &&
@@ -491,7 +491,7 @@ function get_load_heatmap($hosts_up, $host_regex, $metrics, $tpl_data, $sort) {
       continue;
 
     $load = get_load($host, $metrics);
-    $host_load[$host] = $load;
+    $host_load[$host] = $load / $load_scale;
   }
 
   $num_hosts = count($host_load);
@@ -594,7 +594,7 @@ if (!$user['showhosts']) {
   if (array_key_exists($user_metricname, $metrics))
     $units = $metrics[$user_metricname]['UNITS'];
 } else {
-  if (array_key_exists($user_metricname, $metrics[key($metrics)]))
+  if ((!is_null($metrics[key($metrics)])) && array_key_exists($user_metricname, $metrics[key($metrics)]))
     if (isset($metrics[key($metrics)][$user_metricname]['UNITS']))
       $units = $metrics[key($metrics)][$user_metricname]['UNITS'];
   else
@@ -614,7 +614,7 @@ if (! $refresh) {
                                $user['ce'],
                                $conf['zoom_support'],
                                $conf['default_optional_graph_size'],
-                               $cluster[LOCALTIME],
+                               $cluster['LOCALTIME'],
                                $tpl_data);
 
   //////////////////////////////////////////////////////////////////////////////
@@ -735,12 +735,11 @@ if ($user['showhosts'] != 0)
 if (isset($conf['heatmaps_enabled']) and
     $conf['heatmaps_enabled'] == 1 and
     (count($hosts_up) > 0))
-  get_load_heatmap($hosts_up, $user['host_regex'], $metrics, $tpl_data, $user['sort']);
+  get_load_heatmap($hosts_up, $user['host_regex'], $metrics, $conf['load_scale'], $tpl_data, $user['sort']);
 
 $tpl_data->assign("conf", $conf);
 $tpl_data->assign("showhosts", $user['showhosts']);
 
-error_log("reports = " . print_r($reports, TRUE));
 $tpl_data->assign("reports_metricname",
                   isset($reports[$user['metricname']]) &&
                   $reports[$user['metricname']]);
@@ -762,7 +761,7 @@ if (isset($conf['show_stacked_graphs']) and
   show_stacked_graphs($user['clustername'],
 		      $user['metricname'],
 		      $user['range'],
-		      $cluster[LOCALTIME],
+		      $cluster['LOCALTIME'],
 		      $user['host_regex'],
 		      $user['cs'],
 		      $user['ce'],
