@@ -729,7 +729,7 @@ function get_view_graph_elements($view) {
   case "standard":
     // Does view have any items/graphs defined
     if ( count($view['items']) == 0 ) {
-      continue;
+      break;
       // print "No graphs defined for this view. Please add some";
     } else {
       // Loop through graph items
@@ -1121,8 +1121,8 @@ function build_aggregate_graph_config ($graph_type,
                                        $line_width,
                                        $hreg,
                                        $mreg,
-                                       $glegend,
-                                       $exclude_host_from_legend_label,
+                                       $glegend = NULL,
+                                       $exclude_host_from_legend_label = false,
                                        $sortit = true) {
 
   global $conf, $index_array, $hosts, $grid, $clusters, $debug, $metrics;
